# TapisCLI
Tapis CLI is designed to provide a simple to use, versatile way to interface with Tapis services hosted on HPC resources. User can either start the app and use it as a traditional command line applications, or pass commands directly from bash.
Allows you to work with all major Tapis services: Pods, Systems, Files, and Apps in one place. It can also interface directly with services being hosted on Tapis pods, like Neo4j. Although currently Neo4j is the only 3rd party application it can work with, adding support for Postgres and the like will not be difficult.

## Operations
1. to see a list of all commands and their parameters, just enter help

## Current bugs
1. help menu does not list the arguments for server commands, most notably, switch_service. To run this, you must specify switch_service -n (service link)